@@ -11,11 +11,19 @@
 #include <QDBusServiceWatcher>
 #include <QDebug>
 #include <QTimer>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QX11Info>
+#else
+#include <QtGui/private/qtx11extras_p.h>
+#endif
 
 #define USED_MASK (XCB_MOD_MASK_SHIFT | XCB_MOD_MASK_CONTROL | XCB_MOD_MASK_1 | XCB_MOD_MASK_4)
 
-bool XcbEventFilter::nativeEventFilter(const QByteArray &eventType, void *message, long int *result)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+bool XcbEventFilter::nativeEventFilter(const QByteArray &eventType, void *message, long *result)
+#else
+bool XcbEventFilter::nativeEventFilter(const QByteArray &eventType, void *message, qintptr *result)
+#endif
 {
     Q_UNUSED(result);
     if (eventType != "xcb_generic_event_t") {
@@ -171,7 +179,7 @@ App::App(int &argc, char *argv[])
     , m_watcher(new QDBusServiceWatcher(this))
 {
     m_syms = xcb_key_symbols_alloc(QX11Info::connection());
-    installNativeEventFilter(m_eventFilter.data());
+    installNativeEventFilter(m_eventFilter.get());
 
     initIconMap(m_iconMap);
     m_watcher->setConnection(QDBusConnection::sessionBus());
@@ -352,7 +360,7 @@ void App::setDoGrab(bool doGrab)
 
 void App::grabKey()
 {
-    Q_FOREACH (const TriggerKey &key, m_triggersList) {
+    for (const TriggerKey &key : std::as_const(m_triggersList)) {
         xcb_keysym_t sym = key.first;
         uint modifiers = key.second;
         xcb_keycode_t *keycode = xcb_key_symbols_get_keycode(m_syms, sym);
@@ -376,7 +384,7 @@ void App::grabKey()
 
 void App::ungrabKey()
 {
-    Q_FOREACH (const TriggerKey &key, m_triggersList) {
+    for (const TriggerKey &key : std::as_const(m_triggersList)) {
         xcb_keysym_t sym = key.first;
         uint modifiers = key.second;
         xcb_keycode_t *keycode = xcb_key_symbols_get_keycode(m_syms, sym);
