@@ -7,8 +7,7 @@
     SPDX-License-Identifier: LGPL-2.0-only
 */
 
-#ifndef _BALOO_FILE_KCM_H_
-#define _BALOO_FILE_KCM_H_
+#pragma once
 
 #include <KQuickAddons/ManagedConfigModule>
 
@@ -35,15 +34,17 @@ public:
     Q_INVOKABLE void deleteIndex();
     Q_INVOKABLE int rawIndexFileSize();
     Q_INVOKABLE QString prettyIndexFileSize();
+    Q_INVOKABLE void requestReboot();
 
 public Q_SLOTS:
     void load() override;
     void save() override;
 
+Q_SIGNALS:
+    void indexingSettingsChanged();
+
 private:
     BalooData *m_data;
     FilteredFolderModel *m_filteredFolderModel;
 };
 }
-
-#endif
