@@ -3,8 +3,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef COMPONENTCHOOSERTEL_H
-#define COMPONENTCHOOSERTEL_H
+#pragma once
 
 #include "componentchooser.h"
 
@@ -14,5 +13,3 @@ public:
     explicit ComponentChooserTel(QObject *parent);
     void save() override;
 };
-
-#endif // COMPONENTCHOOSERTEL_H
