@@ -31,7 +31,7 @@
 
 #include "timedated_interface.h"
 
-K_PLUGIN_CLASS_WITH_JSON(KclockModule, "clock.json")
+K_PLUGIN_CLASS_WITH_JSON(KclockModule, "kcm_clock.json")
 
 KclockModule::KclockModule(QWidget *parent, const QVariantList &)
     : KCModule(parent)
