@@ -4,11 +4,8 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KEYBOARD_DBUS_H_
-#define KEYBOARD_DBUS_H_
+#pragma once
 
 #define KEYBOARD_DBUS_SERVICE_NAME "org.kde.keyboard"
 #define KEYBOARD_DBUS_OBJECT_PATH "/Layouts"
 #define KEYBOARD_DBUS_CONFIG_RELOAD_MESSAGE "reloadConfig"
-
-#endif /* KEYBOARD_DBUS_H_ */
