@@ -3,11 +3,8 @@
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef PLUGIN_H
-#define PLUGIN_H
+#pragma once
 
 #include <KPluginFactory>
 
 K_PLUGIN_FACTORY_DECLARATION(MousePluginFactory)
-
-#endif // PLUGIN_H
