@@ -4,8 +4,7 @@
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef SPELLCHECKINGDATA_H
-#define SPELLCHECKINGDATA_H
+#pragma once
 
 #include <QObject>
 
@@ -25,5 +24,3 @@ public:
 private:
     SpellCheckingSkeleton *m_settings;
 };
-
-#endif
