@@ -5,7 +5,6 @@
 */
 
 #include "kcmtablet.h"
-#include "devicesmodel.h"
 #include "inputdevice.h"
 #include "tabletevents.h"
 
@@ -91,8 +90,13 @@ public:
 
         for (auto screen : screens) {
             auto geo = screen->geometry();
-            auto it =
-                new QStandardItem(i18nc("model - (x,y widthxheight)", "%1 - (%2,%3 %4×%5)", screen->model(), geo.x(), geo.y(), geo.width(), geo.height()));
+            auto it = new QStandardItem(i18nc("model - (x,y widthxheight)",
+                                              "%1 - (%2,%3 %4×%5)",
+                                              screen->model(),
+                                              QString::number(geo.x()),
+                                              QString::number(geo.y()),
+                                              QString::number(geo.width()),
+                                              QString::number(geo.height())));
             it->setData(screen->name(), Qt::UserRole);
             it->setData(screen->physicalSize(), Qt::UserRole + 1);
             it->setData(screen->size(), Qt::UserRole + 2);
@@ -172,8 +176,10 @@ bool Tablet::isDefaults() const
         return false;
 
     const auto cfg = KSharedConfig::openConfig("kcminputrc");
-    const auto group = cfg->group("ButtonRebinds").group("Tablet");
-    if (group.isValid()) {
+    if (cfg->group("ButtonRebinds").group("Tablet").isValid()) {
+        return false;
+    }
+    if (cfg->group("ButtonRebinds").group("TabletTool").isValid()) {
         return false;
     }
     return m_toolsModel->isDefaults() && m_padsModel->isDefaults();
@@ -193,21 +199,22 @@ void Tablet::save()
     m_toolsModel->save();
     m_padsModel->save();
 
-    const auto cfg = KSharedConfig::openConfig("kcminputrc");
-    auto tabletGroup = cfg->group("ButtonRebinds").group("Tablet");
-    for (auto it = m_unsavedMappings.cbegin(), itEnd = m_unsavedMappings.cend(); it != itEnd; ++it) {
-        auto group = tabletGroup.group(it.key());
-        for (auto itDevice = it->cbegin(), itDeviceEnd = it->cend(); itDevice != itDeviceEnd; ++itDevice) {
-            const auto key = itDevice->toString(QKeySequence::PortableText);
-            const auto button = QString::number(itDevice.key());
-            if (key.isEmpty()) {
-                group.deleteEntry(button, KConfig::Notify);
-            } else {
-                group.writeEntry(button, QStringList{"Key", key}, KConfig::Notify);
+    auto generalGroup = KSharedConfig::openConfig("kcminputrc")->group("ButtonRebinds");
+    for (const auto &device : QStringList{"Tablet", "TabletTool"}) {
+        for (auto it = m_unsavedMappings[device].cbegin(), itEnd = m_unsavedMappings[device].cend(); it != itEnd; ++it) {
+            auto group = generalGroup.group(device).group(it.key());
+            for (auto itDevice = it->cbegin(), itDeviceEnd = it->cend(); itDevice != itDeviceEnd; ++itDevice) {
+                const auto key = itDevice->toString(QKeySequence::PortableText);
+                const auto button = QString::number(itDevice.key());
+                if (key.isEmpty()) {
+                    group.deleteEntry(button, KConfig::Notify);
+                } else {
+                    group.writeEntry(button, QStringList{"Key", key}, KConfig::Notify);
+                }
             }
         }
     }
-    tabletGroup.sync();
+    generalGroup.sync();
     m_unsavedMappings.clear();
 }
 
@@ -216,18 +223,16 @@ void Tablet::defaults()
     m_toolsModel->defaults();
     m_padsModel->defaults();
 
-    const auto tabletGroup = KSharedConfig::openConfig("kcminputrc")->group("ButtonRebinds").group("Tablet");
-    const auto tablets = tabletGroup.groupList();
-    for (const auto &tablet : tablets) {
-        const auto buttons = tabletGroup.group(tablet).keyList();
-        for (const auto &button : buttons) {
-            m_unsavedMappings[tablet][button.toUInt()] = {};
-        }
-    }
-
-    for (auto it = m_unsavedMappings.begin(), itEnd = m_unsavedMappings.end(); it != itEnd; ++it) {
-        for (auto itDevice = it->begin(), itDeviceEnd = it->end(); itDevice != itDeviceEnd; ++itDevice) {
-            *itDevice = {};
+    m_unsavedMappings.clear();
+    const auto generalGroup = KSharedConfig::openConfig("kcminputrc")->group("ButtonRebinds");
+    for (const auto &deviceType : QStringList{"Tablet", "TabletTool"}) {
+        auto tabletGroup = generalGroup.group(deviceType);
+        const auto tablets = tabletGroup.groupList();
+        for (const auto &deviceName : tablets) {
+            const auto buttons = tabletGroup.group(deviceName).keyList();
+            for (const auto &button : buttons) {
+                m_unsavedMappings[deviceType][deviceName][button.toUInt()] = {};
+            }
         }
     }
     Q_EMIT settingsRestored();
@@ -235,7 +240,13 @@ void Tablet::defaults()
 
 void Tablet::assignPadButtonMapping(const QString &deviceName, uint button, const QKeySequence &keySequence)
 {
-    m_unsavedMappings[deviceName][button] = keySequence;
+    m_unsavedMappings["Tablet"][deviceName][button] = keySequence;
+    Q_EMIT settingsRestored();
+}
+
+void Tablet::assignToolButtonMapping(const QString &deviceName, uint button, const QKeySequence &keySequence)
+{
+    m_unsavedMappings["TabletTool"][deviceName][button] = keySequence;
     Q_EMIT settingsRestored();
 }
 
@@ -245,7 +256,7 @@ QKeySequence Tablet::padButtonMapping(const QString &deviceName, uint button) co
         return {};
     }
 
-    if (const auto &device = m_unsavedMappings[deviceName]; device.contains(button)) {
+    if (const auto &device = m_unsavedMappings["Tablet"][deviceName]; device.contains(button)) {
         return device.value(button);
     }
 
@@ -258,6 +269,25 @@ QKeySequence Tablet::padButtonMapping(const QString &deviceName, uint button) co
     return QKeySequence(sequence.constLast());
 }
 
+QKeySequence Tablet::toolButtonMapping(const QString &deviceName, uint button) const
+{
+    if (deviceName.isEmpty()) {
+        return {};
+    }
+
+    if (const auto &device = m_unsavedMappings["TabletTool"][deviceName]; device.contains(button)) {
+        return device.value(button);
+    }
+
+    const auto cfg = KSharedConfig::openConfig("kcminputrc");
+    const auto group = cfg->group("ButtonRebinds").group("TabletTool").group(deviceName);
+    const auto sequence = group.readEntry(QString::number(button), QStringList());
+    if (sequence.size() != 2) {
+        return {};
+    }
+    return QKeySequence(sequence.constLast());
+}
+
 DevicesModel *Tablet::toolsModel() const
 {
     return m_toolsModel;
