@@ -1,20 +1,8 @@
 /*
- * Copyright (C) 2013 Alexander Mezin <mezin.alexander@gmail.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2013 Alexander Mezin <mezin.alexander@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "touchpadengine.h"
 
 #include <QDBusConnection>
@@ -35,9 +23,9 @@ TouchpadEngine::TouchpadEngine(QObject *parent, const QVariantList &args)
 void TouchpadEngine::init()
 {
     OrgKdeKded5Interface kded(QLatin1String("org.kde.kded5"), QLatin1String("/kded"), QDBusConnection::sessionBus());
-    kded.loadModule("touchpad").waitForFinished();
+    kded.loadModule("kded_touchpad").waitForFinished();
 
-    m_daemon = new OrgKdeTouchpadInterface("org.kde.kded5", "/modules/touchpad", QDBusConnection::sessionBus(), this);
+    m_daemon = new OrgKdeTouchpadInterface("org.kde.kded5", "/modules/kded_touchpad", QDBusConnection::sessionBus(), this);
     if (!m_daemon->isValid()) {
         return;
     }
@@ -79,6 +67,6 @@ TouchpadEngine::~TouchpadEngine()
 {
 }
 
-K_EXPORT_PLASMA_DATAENGINE_WITH_JSON(touchpad, TouchpadEngine, "plasma-dataengine-touchpad.json")
+K_PLUGIN_CLASS_WITH_JSON(TouchpadEngine, "plasma-dataengine-touchpad.json")
 
 #include "touchpadengine.moc"
