@@ -1,24 +1,11 @@
 /*
- * Copyright 2017 Roman Gilg <subdiff@gmail.com>
- * Copyright 2019 Atul Bisht <atulbisht26@gmail.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2017 Roman Gilg <subdiff@gmail.com>
+    SPDX-FileCopyrightText: 2019 Atul Bisht <atulbisht26@gmail.com>
 
-#ifndef LIBINPUTCOMMON_H
-#define LIBINPUTCOMMON_H
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
+
+#pragma once
 
 #include <QObject>
 #include <QVariant>
@@ -574,5 +561,3 @@ protected:
     Prop<bool> m_defaultClickMethodClickfinger = Prop<bool>("defaultClickMethodClickfinger");
     Prop<bool> m_clickMethodClickfinger = Prop<bool>("clickMethodClickfinger");
 };
-
-#endif // LIBINPUTCOMMON_H
